| copy_tinytex | R Documentation |
The function copy_tinytex() copies the existing TinyTeX installation
to another directory (e.g., a portable device like a USB stick). The function
use_tinytex() adds the copy of TinyTeX in an existing folder to the
PATH variable of the current system via tlmgr_path(),
so that you can use utilities such as tlmgr and pdflatex,
etc.
copy_tinytex(
from = tinytex_root(),
to = select_dir("Select Destination Directory"),
move = FALSE
)
use_tinytex(from = select_dir("Select TinyTeX Directory"))
from |
The root directory of the TinyTeX installation. For
|
to |
The destination directory where you want to make a copy of TinyTeX.
Like |
move |
Whether to use the new copy and delete the original copy of TinyTeX after copying it. |
You can only copy TinyTeX and use it in the same system, e.g., the Windows version of TinyTeX only works on Windows.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.