The function copy_tinytex() copies the existing TinyTeX installation
to another directory (e.g., a portable device like a USB stick). The function
use_tinytex() adds the copy of TinyTeX in an existing folder to the
PATH variable of the current system via tlmgr_path(),
so that you can use utilities such as tlmgr and pdflatex,
etc.
copy_tinytex(
from = tinytex_root(),
to = select_dir("Select Destination Directory"),
move = FALSE
)use_tinytex(from = select_dir("Select TinyTeX Directory"))
The root directory of the TinyTeX installation. For
copy_tinytex(), the default value tinytex_root() should be a
reasonable guess if you installed TinyTeX via install_tinytex(). For
use_tinytex(), if from is not provided, a dialog for choosing
the directory interactively will pop up.
The destination directory where you want to make a copy of TinyTeX.
Like from in use_tinytex(), a dialog will pop up if to
is not provided in copy_tinytex().
Whether to use the new copy and delete the original copy of TinyTeX after copying it.